<?php
/*
Plugin Name: WP low Profiler
Plugin URI: http://anappleaday.konceptus.net/posts/wp-low-profiler/
Description: Enables a user to create low profile posts/pages that are not published on the homepages, category pages and/or feeds, but at the same accessible by direct permalink, search or, for posts, through the archives, and also visible to search engines.
Version: 1.0.11
Author: Robert Mahfoud
Author URI: http://anappleaday.konceptus.net
Text Domain: wp_low_profiler
*/

/*  Copyright 2009  Robert Mahfoud  (email : robert.mahfoud@gmail.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

global $table_prefix;

define(WPLP_TABLE_NAME, "${table_prefix}lowprofiler_posts");

global $wplp_currentUrl; 
global $wplp_homeUrl;
$wplp_currentUrl = (!empty($_SERVER['HTTPS']) ? "https://":"http://")
		.$_SERVER['SERVER_NAME']
		.($_SERVER['SERVER_PORT'] != '80' ? ":".$_SERVER['SERVER_PORT'] : '')
		.$_SERVER['REQUEST_URI'];
$wplp_currentUrl = strtolower($wplp_currentUrl);
$wplp_homeUrl = strtolower(get_option('home'));
if( substr($wplp_currentUrl, strlen($wplp_currentUrl)-1, 1) == '/' && substr($wplp_homeUrl, strlen($wplp_homeUrl)-1, 1) != '/' )
	$wplp_homeUrl .= '/';
if( substr($wplp_homeUrl, strlen($wplp_homeUrl)-1, 1) == '/' && substr($wplp_currentUrl, strlen($wplp_currentUrl)-1, 1) != '/' )
	$wplp_currentUrl .= '/';

//echo "<!-- WPLP: URL : ".$wplp_currentUrl." -->\n";
//echo "<!-- WPLP: HOME: ".$wplp_homeUrl." -->\n";
//echo "\n<!-- WPLP: Is Admin: ".is_admin()." -->\n";
//echo "\n<!-- WPLP: Is Home: ".wplp_is_home()." -->\n";
//echo "\n<!-- WPLP: Is Category: ".wplp_is_category()." -->\n";
//echo "\n<!-- WPLP: Is Feed: ".wplp_is_feed()." -->\n";

function wplp_is_home() {
	global $wplp_currentUrl; 
	global $wplp_homeUrl;
	return is_home() || ($wplp_currentUrl == $wplp_homeUrl);
}

function wplp_is_feed() {
	return !wplp_is_home() && is_feed();
}

function wplp_is_category() {
	return !wplp_is_home() && !wplp_is_feed() && is_category();
}


// Create Text Domain For Translations
add_action('init', 'wplp_textdomain');
function wplp_textdomain() {
	$plugin_dir = basename(dirname(__FILE__));
	load_plugin_textdomain('wp-low-profiler', ABSPATH."/$plugin_dir", $plugin_dir);
}

// Activating the plugin
function wplp_activate() {
	echo TABLE_NAME;
	if(@is_file(ABSPATH.'/wp-admin/upgrade-functions.php')) {
		include_once(ABSPATH.'/wp-admin/upgrade-functions.php');
	} elseif(@is_file(ABSPATH.'/wp-admin/includes/upgrade.php')) {
		include_once(ABSPATH.'/wp-admin/includes/upgrade.php');
	} else {
		die('We have problem finding your \'/wp-admin/upgrade-functions.php\' and \'/wp-admin/includes/upgrade.php\'');
	}
	
	// Create Low Profiler Posts Table
	$create_sql = "CREATE TABLE  ".WPLP_TABLE_NAME." (".
							  "wplp_post_id bigint(20),".
							  "wplp_flag varchar(255),".
							  "wplp_value varchar(255)".
							")";
	//echo '<pre>'.$create_sql.'<pre>';
	maybe_create_table(WPLP_TABLE_NAME, $create_sql);	
}
//register_activation_hook( __FILE__, 'wplp_activate' );
add_action('activate_wp-low-profiler/wp-low-profiler.php', 'wplp_activate' );

function wplp_update_low_profile($id, $lp_flag, $lp_value) {
	$item = get_post_type($id);
	global $wpdb;
	if( ($item == 'post' && !$lp_value) || ($item == 'page' && (!$lp_value || $lp_value == 'none')) ) {
		wplp_unset_low_profile($item, $id, $lp_flag);
	} else {
		wplp_set_low_profile($item, $id, $lp_flag, $lp_value);
	}
}

function wplp_unset_low_profile($item, $id, $lp_flag) {
	global $wpdb;
	// Delete the flag from the database table
	$wpdb->query("DELETE FROM ".WPLP_TABLE_NAME." WHERE wplp_post_id = $id AND wplp_flag = '$lp_flag'");
}

function wplp_set_low_profile($item, $id, $lp_flag, $lp_value) {
	global $wpdb;	
	// Ensure No Duplicates!
	$check = strval($wpdb->get_var("SELECT wplp_flag FROM ".WPLP_TABLE_NAME." WHERE wplp_post_id = $id AND wplp_flag='$lp_flag'"));
	if(!$check) {
		$wpdb->query("INSERT INTO ".WPLP_TABLE_NAME."(wplp_post_id, wplp_flag, wplp_value) VALUES($id, '$lp_flag', '$lp_value')");
	} elseif( $item == 'page' ) {
		$wpdb->query("UPDATE ".WPLP_TABLE_NAME." set wplp_value = '$lp_value' WHERE wplp_post_id = $id AND wplp_flag = 'page'");
	}
}

// hook function to filter out low profile pages
function wplp_exclude_low_profile_pages($posts) {
	return wplp_exclude_low_profile_items('page', $posts);
}

function wplp_exclude_low_profile_items($item, $posts) {
	if( !is_admin() ) {
		if( $item != 'page' )
			return $posts;
		else {
			global $wpdb;
			// now loop over the pages, and exclude the ones with low profile in this context
			$result = array();
			foreach($posts as $post) {
				$check = strval($wpdb->get_var("SELECT wplp_value FROM ".WPLP_TABLE_NAME." WHERE wplp_post_id = $post->ID AND wplp_flag = 'page'"));
				if( ($check == 'home' && wplp_is_home()) || $check == 'all') {
					// exclude page
				} else
					$result[] = $post;
			}
			return $result;
		}
	} else
		return $posts;
}
// register the filter "the_posts" to hide low profile posts
add_filter('get_pages', 'wplp_exclude_low_profile_pages');

add_action('admin_menu', 'wplp_add_post_edit_meta_box');
function wplp_add_post_edit_meta_box() {
	add_meta_box('lowprofilerdivpost', __('Low Profile Attributes', 'wp-low-profiler'), 'wplp_metabox_post_edit', 'post', 'side');
	add_meta_box('lowprofilerdivpage', __('Low Profile Attributes', 'wp-low-profiler'), 'wplp_metabox_page_edit', 'page', 'side');
}

function wplp_metabox_post_edit() {
	global $wpdb;
	
	$id = isset($_GET['post']) ? intval($_GET['post']) : 0;

	$wplp_home = 0;
	$wplp_category = 0;
	$wplp_feed = 0;
	
	if($id > 0) {
		$flags = $wpdb->get_results("SELECT wplp_flag from ".WPLP_TABLE_NAME." where wplp_post_id = $id", ARRAY_N);
		if( $flags ) {
			foreach($flags as $flag_array) {
				$flag = $flag_array[0];
				${"wplp_$flag"} = 1;
			} 
		}
	}
?>
	<label for="wplp_home" class="selectit"><input type="checkbox" id="wplp_home" name="wplp_home" value="1"<?php checked($wplp_home, 1); ?>/>&nbsp;<?php _e('Hide on the front page.', 'wp-low-profiler'); ?></label>
	<br />
	<label for="wplp_category" class="selectit"><input type="checkbox" id="wplp_category" name="wplp_category" value="1"<?php checked($wplp_category, 1); ?>/>&nbsp;<?php _e('Hide on category page(s).', 'wp-low-profiler'); ?></label>
	<br />
	<label for="wplp_feed" class="selectit"><input type="checkbox" id="wplp_feed" name="wplp_feed" value="1"<?php checked($wplp_feed, 1); ?>/>&nbsp;<?php _e('Hide in feed(s).', 'wp-low-profiler'); ?></label>
	<br />
	<div style="float:right;font-size: xx-small;"><a href="http://wordpress.org/extend/plugins/wp-low-profiler/"><?php _e("Please give 'WP low Profiler' a good rating", 'wp-low-profiler'); ?></a></div>
	<br />
<?php
}

function wplp_metabox_page_edit() {
	global $wpdb;
	
	$id = isset($_GET['post']) ? intval($_GET['post']) : 0;

	$wplp_page = 'none';
	
	if($id > 0) {
		$flags = $wpdb->get_results("SELECT wplp_value from ".WPLP_TABLE_NAME." where wplp_post_id = $id AND wplp_flag = 'page'", ARRAY_N);
		if( $flags )
			$wplp_page = $flags[0][0];
	}
?>
	<label class="selectit"><input type="radio" id="wplp_page_none" name="wplp_page" value="none"<?php checked($wplp_page, 'none'); ?>/>&nbsp;<?php _e('Show normally everywhere.', 'wp-low-profiler'); ?></label>
	<br />
	<br />
	<label class="selectit"><input type="radio" id="wplp_page_all" name="wplp_page" value="all"<?php checked($wplp_page, 'all'); ?>/>&nbsp;<?php _e('Hide everywhere pages are listed (except the sitemap.xml if you generate one automatically).', 'wp-low-profiler'); ?></label>
	<br />
	<br />
	<label class="selectit"><input type="radio" id="wplp_page_home" name="wplp_page" value="home"<?php checked($wplp_page, 'home'); ?>/>&nbsp;<?php _e('Hide when listing pages on the front page only.', 'wp-low-profiler'); ?></label>
	<br />
	<div style="float:right;font-size: xx-small;"><a href="http://wordpress.org/extend/plugins/wp-low-profiler/"><?php _e("Please give 'WP low Profiler' a good rating", 'wp-low-profiler'); ?></a></div>
	<br />
<?php
}

function wplp_save_post($id) {
	$item = get_post_type($id);
	if( $item == 'post' ) {
		$wplp_home = isset($_POST['wplp_home']) ? $_POST['wplp_home'] : 0;
		$wplp_category = isset($_POST['wplp_category']) ? $_POST['wplp_category'] : 0;
		$wplp_feed = isset($_POST['wplp_feed']) ? $_POST['wplp_feed'] : 0;
		
		wplp_update_low_profile($id, 'home', $wplp_home);
		wplp_update_low_profile($id, 'category', $wplp_category);
		wplp_update_low_profile($id, 'feed', $wplp_feed);
	} elseif( $item == 'page' ) {
		$wplp_page = isset($_POST['wplp_page']) ? $_POST['wplp_page'] : 'none';
		wplp_update_low_profile($id, 'page', $wplp_page);
	}	
}
add_action('save_post', 'wplp_save_post');

function wplp_delete_post($post_id) {
	global $wpdb;
	// Delete all post flags from the database table
	$wpdb->query("DELETE FROM ".WPLP_TABLE_NAME." WHERE wplp_id = $post_id");
}
add_action('delete_post', 'wplp_delete_post');

function wplp_query_posts_where($where) {
	// filter posts on one of the three kinds of contexts: home, category, feed
	if( !is_admin() && (wplp_is_feed() || wplp_is_home() || wplp_is_category()) ) {
		$where .= ' AND '.WPLP_TABLE_NAME.'.wplp_post_id IS NULL ';
	}
//	echo "\n<!-- WPLP: ".$where." -->\n";
	return $where;
}

function wplp_query_posts_join($join) {
	// filter posts on one of the three kinds of contexts: home, category, feed
	if( !is_admin() && (wplp_is_feed() || wplp_is_home() || wplp_is_category()) ) {

		if( !$join )
			$join = '';
	
		$join .= ' LEFT JOIN '.WPLP_TABLE_NAME.' ON wp_posts.ID = '.WPLP_TABLE_NAME.'.wplp_post_id ';
		// posts
		$join .= ' AND (wp_posts.post_type = \'post\' ';
		if( wplp_is_home() )
			$join .= ' AND '.WPLP_TABLE_NAME.'.wplp_flag = \'home\' ';
		elseif( wplp_is_category())
			$join .= ' AND '.WPLP_TABLE_NAME.'.wplp_flag = \'category\' ';
		elseif( wplp_is_feed())
			$join .= ' AND '.WPLP_TABLE_NAME.'.wplp_flag = \'feed\' ';
		$join .= ')';
	}
//	echo "\n<!-- WPLP: ".$join." -->\n";
	return $join;
}

add_filter('posts_where_paged', 'wplp_query_posts_where');
add_filter('posts_join_paged', 'wplp_query_posts_join');


//function wplp_query_posts_groupby($x) {
//	echo "\n<!-- WPLP: ".$x." -->\n";
//	return x;
//}
//	function wplp_query_posts_orderby($x) {
//	echo "\n<!-- WPLP: ".$x." -->\n";
//	return x;
//}
//	function wplp_query_posts_limits($x) {
//	echo "\n<!-- WPLP: ".$x." -->\n";
//	return x;
//}
//function wplp_query_posts_fields($x) {
//	echo "\n<!-- WPLP: ".$x." -->\n";
//	return x;
//}
//
//add_filter('posts_groupby', 'wplp_query_posts_groupby');
//add_filter('posts_orderby', 'wplp_query_posts_orderby');
//add_filter('post_limits', 'wplp_query_posts_limits');
//add_filter('posts_fields', 'wplp_query_posts_fields');


?>
